==> percona-server-5.7_5.7.40-43.orig.tar.gz: percona-server-5.7.40-43/storage/tokudb/PerconaFT/ft/CMakeFiles/logformat.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "CXX"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_CXX
  "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/storage/tokudb/PerconaFT/ft/logger/logformat.cc" "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/storage/tokudb/PerconaFT/ft/CMakeFiles/logformat.dir/logger/logformat.cc.o"
  )
set(CMAKE_CXX_COMPILER_ID "GNU")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_CXX
  "HAVE_CONFIG_H"
  "HAVE_TLSv13"
  "LZ4_DISABLE_DEPRECATE_WARNINGS"
  "MYSQL_TOKUDB_ENGINE=1"
  "MYSQL_VERSION_ID=50740"
  "TOKU_MYSQL_WITH_PFS"
  "_DEFAULT_SOURCE"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "_LARGEFILE64_SOURCE"
  "_XOPEN_SOURCE=600"
  "__LONG_LONG_SUPPORTED"
  "__STDC_FORMAT_MACROS"
  "__STDC_LIMIT_MACROS"
  "__STDC_WANT_LIB_EXT1__=1"
  )

# The include file search paths:
set(CMAKE_CXX_TARGET_INCLUDE_PATH
  "storage/tokudb/PerconaFT/buildheader"
  "extra/lz4/lz4-1.9.3"
  "extra/zlib/zlib-1.2.12"
  "include"
  "extra/rapidjson/include"
  "libbinlogevents/include"
  "libbinlogevents/export"
  "storage/tokudb/PerconaFT/./xz/include"
  "storage/tokudb/PerconaFT/./snappy/include"
  "storage/tokudb/PerconaFT/portability"
  "storage/tokudb/PerconaFT"
  "/usr/local/include"
  "storage/tokudb/PerconaFT/ft"
  )

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/storage/tokudb/PerconaFT/portability/CMakeFiles/tokuportability_static.dir/DependInfo.cmake"
  )

# Fortran module output directory.
set(CMAKE_Fortran_TARGET_MODULE_DIR "")

==> percona-server-5.7_5.7.41-44.orig.tar.gz: percona-server-5.7.41-44/storage/tokudb/PerconaFT/ft/CMakeFiles/logformat.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "CXX"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_CXX
  "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/storage/tokudb/PerconaFT/ft/logger/logformat.cc" "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/storage/tokudb/PerconaFT/ft/CMakeFiles/logformat.dir/logger/logformat.cc.o"
  )
set(CMAKE_CXX_COMPILER_ID "GNU")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_CXX
  "HAVE_CONFIG_H"
  "HAVE_TLSv13"
  "LZ4_DISABLE_DEPRECATE_WARNINGS"
  "MYSQL_TOKUDB_ENGINE=1"
  "MYSQL_VERSION_ID=50741"
  "TOKU_MYSQL_WITH_PFS"
  "_DEFAULT_SOURCE"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "_LARGEFILE64_SOURCE"
  "_XOPEN_SOURCE=600"
  "__LONG_LONG_SUPPORTED"
  "__STDC_FORMAT_MACROS"
  "__STDC_LIMIT_MACROS"
  "__STDC_WANT_LIB_EXT1__=1"
  )

# The include file search paths:
set(CMAKE_CXX_TARGET_INCLUDE_PATH
  "storage/tokudb/PerconaFT/buildheader"
  "extra/lz4/lz4-1.9.4/lib"
  "extra/zlib/zlib-1.2.12"
  "include"
  "extra/rapidjson/include"
  "libbinlogevents/include"
  "libbinlogevents/export"
  "storage/tokudb/PerconaFT/./xz/include"
  "storage/tokudb/PerconaFT/./snappy/include"
  "storage/tokudb/PerconaFT/portability"
  "storage/tokudb/PerconaFT"
  "/usr/local/include"
  "storage/tokudb/PerconaFT/ft"
  )

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/storage/tokudb/PerconaFT/portability/CMakeFiles/tokuportability_static.dir/DependInfo.cmake"
  )

# Fortran module output directory.
set(CMAKE_Fortran_TARGET_MODULE_DIR "")
